pub fn apply_chain(
frame: VideoFrame,
chain: &[VideoFilter],
) -> Result<VideoFrame>Expand description
Apply a whole stateless chain to a frame, in order. Returns an error if
the chain contains an overlay (use FilterChain for that).
pub fn apply_chain(
frame: VideoFrame,
chain: &[VideoFilter],
) -> Result<VideoFrame>Apply a whole stateless chain to a frame, in order. Returns an error if
the chain contains an overlay (use FilterChain for that).