pub fn encode_delta_snapshot_for_client(
schema: &Schema,
tick: SnapshotTick,
baseline_tick: SnapshotTick,
baseline: &Snapshot,
current: &Snapshot,
limits: &CodecLimits,
out: &mut [u8],
) -> CodecResult<usize>Expand description
Encodes a delta snapshot for a client-specific view.
This assumes baseline and current are already filtered for the client interest set.
Updates are encoded in sparse mode to optimize for small per-client packets.