pub fn select_baseline_tick<T>(
store: &BaselineStore<T>,
ack_tick: SnapshotTick,
) -> Option<SnapshotTick>Expand description
Selects the latest baseline tick at or before the ack tick.
pub fn select_baseline_tick<T>(
store: &BaselineStore<T>,
ack_tick: SnapshotTick,
) -> Option<SnapshotTick>Selects the latest baseline tick at or before the ack tick.