hevc_first_slice_nal_offset

Function hevc_first_slice_nal_offset 

pub fn hevc_first_slice_nal_offset(data: &[u8]) -> Option<u32>
Scan an Annex-B HEVC sample and return the offset, in bytes from the start of data, where the first coded-slice NAL begins (the byte AFTER the start code). Vulkan slice_segment_offsets wants offsets to NAL-unit first bytes, not to start codes.