Crate conduit_core

Crate conduit_core 

conduit-core

Binary IPC core for Tauri v2. Provides a binary codec, synchronous dispatch table, and in-process ring buffer for the conduit:// custom protocol.

Re-exports

pub use codec::FRAME_HEADER_SIZE;
pub use codec::FrameHeader;
pub use codec::MsgType;
pub use codec::PROTOCOL_VERSION;
pub use codec::WireDecode;
pub use codec::WireEncode;
pub use codec::frame_unwrap;
pub use codec::frame_wrap;
pub use error::ConduitError;
pub use ringbuf::ConduitRingBuffer;
pub use router::DispatchTable;

Modules

codec
Binary frame format and wire encoding traits for conduit.
error
Error types for the conduit IPC layer.
ringbuf
In-process ring buffer for high-frequency streaming.
router
Command dispatch table with synchronous handlers.