pub fn encode_delta_snapshot(
schema: &Schema,
tick: SnapshotTick,
baseline_tick: SnapshotTick,
baseline: &Snapshot,
current: &Snapshot,
limits: &CodecLimits,
out: &mut [u8],
) -> CodecResult<usize>Expand description
Encodes a delta snapshot into the provided output buffer.
Baseline and current snapshots must have entities sorted by EntityId.